![PyTamaro Logo](https://github.com/LuCEresearchlab/pytamaro/raw/main/docs/images/PyTamaro-horizontal-white-bg.png)

![Test](https://github.com/LuCEresearchlab/pytamaro/workflows/Test/badge.svg)
![Lint](https://github.com/LuCEresearchlab/pytamaro/workflows/Lint/badge.svg)
![TypeCheck](https://github.com/LuCEresearchlab/pytamaro/workflows/TypeCheck/badge.svg)
<a href="https://pypi.org/project/pytamaro/">
    <img alt="PyPI" src="https://img.shields.io/pypi/v/pytamaro">
</a>

**PyTamaro** is an educational library for Python designed to teach programming using graphics.

### 📃 Background and Design Principles

This [SPLASH-E paper](https://www.chiodini.org/publications/splashe23-pytamaro.pdf) describes the design principles underpinning the library.

### ✨ Examples and Online Environment

[PyTamaro Web](https://pytamaro.si.usi.ch/) is an online platform that provides additional resources for PyTamaro.

- Run your Python programs with PyTamaro directly in the browser (without the need to create an account or install something on your computer!)
- 100+ activities that showcase what is possible to create with PyTamaro
- A selection of curricula that guide you through a curated sequence of activities

### 💻 Installation

As simple as 
```sh
pip install pytamaro
```

You can install PyTamaro using Python 3.9 - 3.12 on all major operating systems and architectures.

### 📚 Documentation

The full documentation of the public API is available on [ReadTheDocs](https://pytamaro.readthedocs.io/).

### 🧑‍💻 Contributing

If you find what looks like a bug, please [create an issue](https://github.com/LuCEresearchlab/pytamaro/issues/new) so that we can investigate.

The development process, which contributors should follow, is described in the [CONTRIBUTING.md file](https://github.com/LuCEresearchlab/pytamaro/blob/main/CONTRIBUTING.md). 
